Generate password
=======================

After you create the sitekey, password of the site can be generated by

.. code-block:: bash

 > passme site [master]

where

* site: site name
* master: master password

when the master password is not given at the command line argument, it is prompted. The comment of the sitekey is shown first and after you provide the master password, the generated password is shown and copied to the clipboard. See the example as follows.

.. code-block::

 > passme google
 Master password: (input master password)
 ID: sekifake
 https://google.com/
 OT9BD5h6cHmWlN
 Password copied to clipboard.

When the site name is not found in sitekey, the provided site name is searched in comments. If found, they are shown as suggested site name. Therefore it is recommended to provide keywords of the site in the comment so that the site name can easily be recalled when you forget it.

----

Toppage_

.. _Toppage: README.rst
